/*
    Copyright (C) 2008-2010  Lukas Sommer < SommerLuk at gmail dot com >

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef IMPORTKRADIORIPPERSETTINGS_H
#define IMPORTKRADIORIPPERSETTINGS_H

#include <QString>

/** \brief This class provides static functions to import the settings from KRadioRipper.

    \warning Use these functions only \e after creating a KApplication object!
    \warning It changes \e settings_general and the streamlist XML file. While the changes
             in \e settings_general are available immediately, the streamlist seems to be
             not reloaded. So you \e must call this function \e before creating #MainWindow.
*/
class importKradioripperSettings
{
  public:
    /** Asks the user if he wants to import KRadioRipper's settings.
        @param use_dontAskAgainName Make use of the dontAskAgainName system of KMessageDialog. */
    static void askForImport(bool use_dontAskAgainName = false);
    /** Imports the settings of KRadioRipper if this had been requested by the user previously. */
    static void importSettingsIfDesired();
  private:
    /** Creates an empty stream config file and returns its name. The code is mostly
    *   copied from #radioStation::helper_setupConfigSystem(). */
    static QString allocateStreamFile();
    /** The code is just copied from #radioStation::helper_locateConfigfile(). */
    static QString helper_locateConfigfile(const QString & configfileName);
     /** Copied from #stationlistModel::helper_stationlistXmlFilepath().
         @returns The full path to the XML file that contains the station list. */
    static QString helper_stationlistXmlFilepath();
    /** Imports KRadioRipper's settings. */
    static void importSettings();
};

#endif
