/*
    Copyright (C) 2008-2010  Lukas Sommer < SommerLuk at gmail dot com >

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "listensupport.h"

#include <QTimer>
#include <QCoreApplication>
#include <QEventLoop>

listenSupport::listenSupport(QObject *parent) : QObject(parent)
{
  relayPort = -1;
  station = 0;
  setIsPlaying(false);
  media = new Phonon::MediaObject(this);
  audioOutput = new Phonon::AudioOutput(Phonon::MusicCategory, this);
  createPath(media, audioOutput);
  connect(media, SIGNAL(stateChanged(Phonon::State, Phonon::State )),
          this, SLOT(processNewState(Phonon::State)));
}

listenSupport::~listenSupport()
{
  delete audioOutput;
  delete media;
}

void listenSupport::setStation(radioStation *newStation)
{
  if (newStation != station) {
    if (station) {
      disconnect(station, 0, this, 0);
    };
    // change station
    station = newStation;
    // connect new station
    if (station) {
      connect(station,
              SIGNAL(relayPortChanged(qlonglong, PropertyValue)),
              this,
              SLOT(setNoStation()));
      setRelayPort(0, station->relayPort());
      connect(station,
              SIGNAL(destroyed(QObject *)),
              this,
              SLOT(setNoStation()));
    } else {
      setRelayPort(0, PropertyValue());
    };
  };
};

void listenSupport::setNoStation()
{
  setStation(0);
}

void listenSupport::setRelayPort(qlonglong, PropertyValue value)
{
  if (value.type == PropertyValue::value) {
    const qlonglong newPort = value.internalValue.toLongLong();
    if (relayPort != newPort) {
      relayPort = newPort;
      reloadListening();
    };
  } else {
    if (relayPort >= 0) {
      relayPort = -1;
      reloadListening();
    };
  };
}

void listenSupport::reloadListening()
{
  if (relayPort >= 0) {
    media->setCurrentSource(QString("http://localhost:%1").arg(relayPort));
    media->play();
  } else {
    media->stop();
  };
}

bool listenSupport::isPlaying() const
{
  return internal_isPlaying;
}

void listenSupport::setIsPlaying(bool newValue)
{
  if (newValue != internal_isPlaying) {
    internal_isPlaying = newValue;
    emit isPlayingChanged(newValue);
  };
}

void listenSupport::processNewState(Phonon::State newstate)
{
  setIsPlaying(newstate == Phonon::LoadingState ||
               newstate == Phonon::PlayingState ||
               newstate == Phonon::BufferingState);
}
