/*
    Copyright (C) 2008-2010  Lukas Sommer < SommerLuk at gmail dot com >

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "settings_stream_widget_splitting.h"

#include <QLabel>
#include <QPalette>
#include <QStackedWidget>
#include <KButtonGroup>
#include <KTextEditor/ConfigInterface>
#include <KTextEditor/EditorChooser>

settings_stream_widget_splitting::settings_stream_widget_splitting(QWidget *parent)
  : QStackedWidget(parent)
{
  setupUi(this);
  connect(kcfg_silenceWindow,
           SIGNAL(valueChanged(int)),
           this,
           SLOT(correct_search_window(int)));
  connect(kcfg_searchWindow,
           SIGNAL(valueChanged(int)),
           this,
           SLOT(correct_silence_window(int)));
  // Get a pointer to the implementation of KTextEditor.
  // We may never delete this object!
  KTextEditor::Editor *parse_rule_editor = KTextEditor::EditorChooser::editor();
  if (!parse_rule_editor) {
    parse_rule_document = 0;
    parse_rule_widget = new QLabel(
      i18nc("@info", "No KDE text editor component found. Please check your KDE installation."),
      this);
  } else {
    parse_rule_document = parse_rule_editor->createDocument(this);
    parse_rule_document->setHighlightingMode("RPM Spec"); // TODO korrekten Wert einsetzen
    parse_rule_widget = parse_rule_document->createView(kbuttongroup_metadataprocessing);
    KTextEditor::ConfigInterface *interface =
      qobject_cast<KTextEditor::ConfigInterface *>(parse_rule_widget);
    if (interface) {
      defaultBackground = interface->configValue("background-color").value<QColor>();
    };
    const int parse_rule_widget_min_size = parse_rule_widget->fontMetrics().lineSpacing() * 12;
    parse_rule_widget->setMinimumSize(parse_rule_widget_min_size, parse_rule_widget_min_size);
    parse_rule_widget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
  };
  metadataprocessing_layout->addWidget(parse_rule_widget);
  setEnable_parse_rule_widget(kcfg_customMetadataProcessing->isChecked());
  connect(kcfg_customMetadataProcessing,
          SIGNAL(toggled(bool)),
          this,
          SLOT(setEnable_parse_rule_widget(const bool)));
  connect(kcfg_parseRules,
          SIGNAL(textChanged(const QString &)),
          this,
          SLOT(parse_rule_document_setText_withoutUpdating(const QString &)));
  connect(parse_rule_document,
          SIGNAL(textChanged(KTextEditor::Document *)),
          this,
          SLOT(kcfg_parseRules_setText_withoutUpdating(KTextEditor::Document *)));
  connect(kcfg_customMetadataProcessing,
          SIGNAL(toggled(bool)),
          this,
          SLOT(set_UI_customMetadataProcessing_withoutUpdating(const bool)));
  connect(customMetadataProcessing_true,
          SIGNAL(toggled(bool)),
          this,
          SLOT(set_kcfg_customMetadataProcessing_withoutUpdating(const bool)));
}

settings_stream_widget_splitting::~settings_stream_widget_splitting()
{
  // make sure that parse_rule_widget is deleted _befor_ parse_rule_document:
  delete parse_rule_widget;
}

void settings_stream_widget_splitting::kcfg_parseRules_setText_withoutUpdating(
  KTextEditor::Document *document)
{
  if (document) {
    disconnect(kcfg_parseRules,
               SIGNAL(textChanged(const QString &)),
               this,
               SLOT(parse_rule_document_setText_withoutUpdating(const QString &)));
    kcfg_parseRules->setText(document->text());
    connect(kcfg_parseRules,
            SIGNAL(textChanged(const QString &)),
            this,
            SLOT(parse_rule_document_setText_withoutUpdating(const QString &)));
  };
}

void settings_stream_widget_splitting::parse_rule_document_setText_withoutUpdating(
  const QString & text)
{
  if (parse_rule_document) {
    disconnect(parse_rule_document,
               SIGNAL(textChanged(KTextEditor::Document *)),
               this,
               SLOT(kcfg_parseRules_setText_withoutUpdating(KTextEditor::Document *)));
    parse_rule_document->setText(text);
    connect(parse_rule_document,
            SIGNAL(textChanged(KTextEditor::Document *)),
            this,
            SLOT(kcfg_parseRules_setText_withoutUpdating(KTextEditor::Document *)));
  };
}

void settings_stream_widget_splitting::setEnable_parse_rule_widget(const bool enabled)
{
  parse_rule_widget->setEnabled(enabled);
  KTextEditor::ConfigInterface *interface =
    qobject_cast<KTextEditor::ConfigInterface *>(parse_rule_widget);
  if (interface) {
    if (enabled) {
      interface->setConfigValue("background-color", defaultBackground);
    } else {
      interface->setConfigValue(
        "background-color",
        kbuttongroup_metadataprocessing->palette().color(QPalette::Window));
    };
  };
}

void settings_stream_widget_splitting::correct_search_window(const int silence_window)
{
  if (kcfg_searchWindow->value() <= silence_window) {
    kcfg_searchWindow->setValue(silence_window + 1);
  };
}

void settings_stream_widget_splitting::correct_silence_window(const int search_window)
{
  if (kcfg_silenceWindow->value() >= search_window) {
    kcfg_silenceWindow->setValue(search_window - 1);
  };
}

void settings_stream_widget_splitting::set_UI_customMetadataProcessing_withoutUpdating(
  const bool enabled)
{
  disconnect(customMetadataProcessing_true,
             SIGNAL(toggled(bool)),
             this,
             SLOT(set_kcfg_customMetadataProcessing_withoutUpdating(const bool)));
  if (enabled) {
    customMetadataProcessing_true->setChecked(true);
  } else {
    customMetadataProcessing_false->setChecked(true);
  };
  connect(customMetadataProcessing_true,
          SIGNAL(toggled(bool)),
          this,
          SLOT(set_kcfg_customMetadataProcessing_withoutUpdating(const bool)));
}

void settings_stream_widget_splitting::set_kcfg_customMetadataProcessing_withoutUpdating(
  const bool enabled)
{
  disconnect(kcfg_customMetadataProcessing,
             SIGNAL(toggled(bool)),
             this,
             SLOT(set_UI_customMetadataProcessing_withoutUpdating(const bool)));
  kcfg_customMetadataProcessing->setChecked(enabled);
  connect(kcfg_customMetadataProcessing,
          SIGNAL(toggled(bool)),
          this,
          SLOT(set_UI_customMetadataProcessing_withoutUpdating(const bool)));
}
