/*
    Copyright (C) 2008-2010  Lukas Sommer < SommerLuk at gmail dot com >

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SETTINGS_STREAM_WIDGET_SPLITTING_H
#define SETTINGS_STREAM_WIDGET_SPLITTING_H

#include "ui_settings_stream_widget_splitting.h"

#include <KTextEditor/Document>
#include <KTextEditor/Editor>
#include <KTextEditor/View>

/** \brief Widget for the "splitting" options in the stream configuration
*          (for use with a KConfigDialog).
*
* It uses the UI that is generated with Qt-Designer.
*
* \sa settings_stream */
class settings_stream_widget_splitting
  : public QStackedWidget, private Ui::settings_stream_widget_splitting
{
  Q_OBJECT

  public:
    /** The constructor.
        @param parent The parent widget. */
    settings_stream_widget_splitting(QWidget *parent=0);
    /** The destructor. */
    virtual ~settings_stream_widget_splitting();

  protected:
    /** This member holds the default background color that is used by #parse_rule_widget.
    *   \note A correct value is only provided if #parse_rule_widget is
    *   a <tt>KTextEdit::View</tt>. */
    QColor defaultBackground;
    /** The object that represents the "parse rule" file.
    * \warning This may be \e 0 if no KTextEditor implementation is available on the
    * users system. */
    KTextEditor::Document *parse_rule_document;
    /** The widget that represents the "parse rule" file.
    * \warning This may be just an error message if no KTextEditor implementation is available on
    * the users system. */
    QWidget *parse_rule_widget;

  protected slots:
    /** This method corrects (if necessary) the search window,
    *   if the silence window has changed.
    *   (The search window must be \e always bigger
    *   than the silence window.)
    *
    *   @param silence_window the new value of the silence window
    *
    *   Normally this slot in connected to the signal
    *   <tt>valueChanged</tt> of the silence window. */
    void correct_search_window(const int silence_window);
    /** This method corrects (if necessary) the silence window,
    *   if the search window has changed.
    *   (The search window must be \e always bigger
    *   than the silence window.)
    *
    *   @param search_window the new value of the search window
    *
    *   Normally this slot in connected to the signal
    *   <tt>valueChanged</tt> of the search window. */
    void correct_silence_window(const int search_window);
    /** Will set the text of <tt>kcfg_parseRules</tt> without updating
        #parse_rule_document.
        @param document A pointer to the document from which the text is fetched.
        It is save to pass a NULL pointer here; if so, this slot does simply nothing. */
    void kcfg_parseRules_setText_withoutUpdating(KTextEditor::Document *document);
    /** Will set the text of #parse_rule_document without updating
        <tt>kcfg_parseRules</tt>.
        @param text The text that will be applied.
        \note It is save to call this slot, also when #parse_rule_document doesn't exist;
        if so, this slot does simply nothing. */
    void parse_rule_document_setText_withoutUpdating(const QString & text);
    /** Will set the UI representation of customMetadataProcessing without updating
        <tt>kcfg_customMetadataProcessing</tt>.
        @param enabled The value to be applied. */
    void set_UI_customMetadataProcessing_withoutUpdating(const bool enabled);
    /** Will set <tt>kcfg_customMetadataProcessing</tt> without updating
        the UI representation of customMetadataProcessing.
        @param enabled The value to be applied. */
    void set_kcfg_customMetadataProcessing_withoutUpdating(const bool enabled);
    /** Enables or disables #parse_rule_widget.
    * @param enabled This value is applied to the property "enabled" of
    * #parse_rule_widget. */
    void setEnable_parse_rule_widget(const bool enabled);
};

#endif
