/*
    Copyright (C) 2008-2010  Lukas Sommer < SommerLuk at gmail dot com >

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "stationlistitem.h"

#include <QFile>

stationlistItem::stationlistItem(const QString & folderName)
{
  m_itemType = folder;
  m_folderName = folderName;
  initialize();
}

stationlistItem::stationlistItem(radioStation *streamObject)
{
  m_itemType = stream;
  m_radiostation = streamObject;
  initialize();
};

stationlistItem::~stationlistItem()
{
  foreach (stationlistItem *entry, childItems) {
    delete entry;
  };
}

void stationlistItem::initialize()
{
  parentItem = 0;
  self = this;
}

int stationlistItem::childCount() const
{
  return childItems.size();
}

stationlistItem *stationlistItem::child(int row) const
{
  if (childItems.size() > row) {
    return childItems.value(row);
  } else {
    return 0;
  };
}

bool stationlistItem::appendChild(stationlistItem *child)
{
  if (m_itemType == folder) {
    child->parentItem = this;
    childItems.append(child);
    return true;
  } else {
    return false;
  };
}

bool stationlistItem::insertChild(stationlistItem *child, int row)
{
  if (m_itemType == folder) {
    if (row < 0) {
      row = 0;
    } else if (row > childCount()) {
      row = childCount();
    };
    child->parentItem = this;
    childItems.insert(row, child);
    return true;
  } else {
    return false;
  };
}

void stationlistItem::detach()
{
  if (parentItem) {  // this is a child item
    parentItem->childItems.removeAt(row());
    parentItem = 0;
  };
}

int stationlistItem::row() const
{
  if (parentItem) {  // this is a child item
    return parentItem->childItems.indexOf(self);
  } else {  // this is a root item
    return 0;
  };
}

stationlistItem *stationlistItem::parent() const
{
  return parentItem;
}

stationlistItem::itemType stationlistItem::type() const
{
  return m_itemType;
};

radioStation *stationlistItem::streamObject() const
{
  return m_radiostation;
};

QString stationlistItem::folderName() const
{
  return m_folderName;
};

void stationlistItem::setFolderName(const QString & folderName)
{
  m_folderName = folderName;
}
